@@ -21,6 +21,6 @@ for name, action in (
     ("inventory_release_create", "release"),
 ):
     inventory_mock.post(
-        path__regex=fr"/private/api/v1/inventory/(?P<warehouse_code>\w+)/{action}/$",
+        path__regex=rf"/private/api/v1/inventory/(?P<warehouse_code>\w+)/{action}/$",
         name=name,
     ).mock(return_value=Response(HTTPStatus.NO_CONTENT))
